pub struct GlobalRenderNodeKey(/* private fields */);Trait Implementations
Sourceimpl Clone for GlobalRenderNodeKey
impl Clone for GlobalRenderNodeKey
Sourcefn clone(&self) -> GlobalRenderNodeKey
fn clone(&self) -> GlobalRenderNodeKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GlobalRenderNodeKey
impl Debug for GlobalRenderNodeKey
Sourceimpl Default for GlobalRenderNodeKey
impl Default for GlobalRenderNodeKey
Sourcefn default() -> GlobalRenderNodeKey
fn default() -> GlobalRenderNodeKey
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for GlobalRenderNodeKey
impl From<KeyData> for GlobalRenderNodeKey
Sourceimpl Hash for GlobalRenderNodeKey
impl Hash for GlobalRenderNodeKey
Sourceimpl Key for GlobalRenderNodeKey
impl Key for GlobalRenderNodeKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for GlobalRenderNodeKey
impl Ord for GlobalRenderNodeKey
Sourcefn cmp(&self, other: &GlobalRenderNodeKey) -> Ordering
fn cmp(&self, other: &GlobalRenderNodeKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GlobalRenderNodeKey
impl PartialEq for GlobalRenderNodeKey
Sourceimpl PartialOrd for GlobalRenderNodeKey
impl PartialOrd for GlobalRenderNodeKey
impl Copy for GlobalRenderNodeKey
impl Eq for GlobalRenderNodeKey
impl StructuralPartialEq for GlobalRenderNodeKey