pub struct RenderInstanceKey(/* private fields */);Trait Implementations
Sourceimpl Clone for RenderInstanceKey
impl Clone for RenderInstanceKey
Sourcefn clone(&self) -> RenderInstanceKey
fn clone(&self) -> RenderInstanceKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderInstanceKey
impl Debug for RenderInstanceKey
Sourceimpl Default for RenderInstanceKey
impl Default for RenderInstanceKey
Sourcefn default() -> RenderInstanceKey
fn default() -> RenderInstanceKey
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for RenderInstanceKey
impl From<KeyData> for RenderInstanceKey
Sourceimpl Hash for RenderInstanceKey
impl Hash for RenderInstanceKey
Sourceimpl Key for RenderInstanceKey
impl Key for RenderInstanceKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for RenderInstanceKey
impl Ord for RenderInstanceKey
Sourcefn cmp(&self, other: &RenderInstanceKey) -> Ordering
fn cmp(&self, other: &RenderInstanceKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RenderInstanceKey
impl PartialEq for RenderInstanceKey
Sourceimpl PartialOrd for RenderInstanceKey
impl PartialOrd for RenderInstanceKey
impl Copy for RenderInstanceKey
impl Eq for RenderInstanceKey
impl StructuralPartialEq for RenderInstanceKey